@@ -1,7 +1,8 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.19_05'; # TRIAL VERSION
+our $VERSION = '1.19_06'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 use 5.008001;
@@ -88,8 +89,6 @@ sub script_compiles {
     $error eq '' and $exit == 0 and $signal == 0 and $stderr =~ /syntax OK\s+\z/si
   );
 
-  rmtree($dir);
-
   my $test = Test::Builder->new;
   $test->ok( $ok, $_[0] || "Script $unix compiles" );
   $test->diag( "$exit - $stderr" ) unless $ok;
@@ -105,7 +104,7 @@ sub script_compiles {
 # safer as very long argument lists can break calls to system
 sub _preload_module
 {
-  my $dir = tempdir( CLEANUP => 1 );
+  my $dir = tempdir( '.test-script-XXXXX', DIR => File::Spec->curdir, CLEANUP => 1 );
   # this is hopefully a pm file that nobody would use
   my $filename = File::Spec->catfile($dir, '__TEST_SCRIPT__.pm');
   my $fh;
@@ -143,7 +142,6 @@ sub script_runs {
 
     if(ref($opt->{stdin}) eq 'SCALAR')
     {
-      $DB::single = 1;
       $filename = File::Spec->catfile(
         tempdir(CLEANUP => 1),
         'stdin.txt',
@@ -174,8 +172,6 @@ sub script_runs {
   my $signal = $? ? ($? & 127) : 0;
   my $ok     = !! ( $error eq '' and $exit == $opt->{exit} and $signal == $opt->{signal} );
 
-  rmtree($dir);
-
   my $test = Test::Builder->new;
   $test->ok( $ok, $_[0] || "Script $unix runs" );
   $test->diag( "$exit - $stderr" ) unless $ok;
@@ -346,7 +342,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.19_05
+version 1.19_06
 
 =head1 SYNOPSIS
 
